@@ -1,5 +1,7 @@
 from ast import *
 import meta
+from meta.asttools import print_ast
+from itertools import chain
 
 from .helpers import *
 
@@ -15,11 +17,13 @@ def transform_function(func_tree):
     # Transform tests to pattern matching
     for test in func_tree.body:
         cond = test.test
+        # print 'no vars in ',
+        print_ast(cond)
 
-        if isinstance(cond, (Num, Str, List, Tuple)) and not has_vars(cond):
+        if isinstance(cond, (Num, Str, List, Tuple, Dict)) and not has_vars(cond):
             test.test = make_eq(N('value'), cond)
 
-        if isinstance(cond, (Num, Str, Name, Compare, List, Tuple, Dict, BinOp)):
+        elif isinstance(cond, (Num, Str, Name, Compare, List, Tuple, Dict, BinOp)):
             tests, assigns = destruct_to_tests_and_assigns(N('value'), cond)
             test.test = BoolOp(op=And(), values=tests) if tests else V(1)
             test.body = assigns + test.body
@@ -30,6 +34,8 @@ def transform_function(func_tree):
     func_tree.body = map(wrap_tail_expr, func_tree.body)
     func_tree.body.append(Raise(type=N('Mismatch'), inst=None, tback=None))
 
+    print meta.dump_python_source(func_tree)
+
 
 def destruct_to_tests_and_assigns(topic, pattern):
     if isinstance(pattern, (Num, Str)):
@@ -84,8 +90,15 @@ def wrap_tail_expr(if_expr):
         if_expr.body[-1] = Return(value=if_expr.body[-1].value)
     return if_expr
 
+
 def has_vars(expr):
-    if isinstance(expr, Tuple):
+    if isinstance(expr, (Tuple, List)):
         return any(has_vars(el) for el in expr.elts)
+    elif isinstance(expr, Dict):
+        return any(has_vars(e) for e in chain(expr.values, expr.keys))
+    elif isinstance(expr, (Name, Compare)):
+        return True
+    elif isinstance(expr, (Num, Str)):
+        return False
     else:
-        return isinstance(expr, (Name, Compare))
+        raise TypeError("Don't know how to handle %s" % expr)
